@@ -14,7 +14,9 @@ except ImportError:
 
 def login(client):
     # Create a user
-    User.objects.create_superuser(username='test', email='test@email.com', password='password')
+    user = User.objects.create_superuser(username='test', email='test@email.com', password='password')
 
     # Login
     client.login(username='test', password='password')
+
+    return user
