@@ -94,6 +94,12 @@ $(function(){
     });
 
     $(".nav-main .more > a").bind('click keydown', function(){
+        var currentAlt = $(this).data('altstate');
+        var newAlt = $(this).html();
+
+        $(this).html(currentAlt);
+        $(this).data('altstate', newAlt);
+        $(this).toggleClass('icon-arrow-up icon-arrow-down');
         $(this).parent().find('ul').toggle('fast');
         return false;
     });
@@ -116,15 +122,15 @@ $(function(){
             clearTimeout($.data(this, 'timer'));
             var wait = setTimeout(search, 200);
             $(this).data('timer', wait);
-        });  
+        });
 
         // auto focus on search box
-        $(window.headerSearch.termInput).trigger('focus'); 
+        $(window.headerSearch.termInput).trigger('focus');
 
         function search () {
-            var workingClasses = "working icon icon-spinner"
+            var workingClasses = "icon-spinner";
 
-            $(window.headerSearch.termInput).parent().addClass(workingClasses); 
+            $(window.headerSearch.termInput).parent().addClass(workingClasses);
             search_next_index++;
             var index = search_next_index;
             $.ajax({
@@ -133,13 +139,14 @@ $(function(){
                 success: function(data, status) {
                     if (index > search_current_index) {
                         search_current_index = index;
-                        $(window.headerSearch.targetOutput).html(data);
+                        $(window.headerSearch.targetOutput).html(data).slideDown(800);
+                        window.history.pushState(null, "Search results", "?q=" + $(window.headerSearch.termInput).val());
                     }
                 },
                 complete: function(){
-                    $(window.headerSearch.termInput).parent().removeClass(workingClasses); 
+                    $(window.headerSearch.termInput).parent().removeClass(workingClasses);
                 }
             });
-        };
+        }
     }
 });
