@@ -28,14 +28,13 @@ class GravatarUrlNode(template.Node):
             return ''
 
         default = "blank"
-        size = self.size
+        size = int(self.size) * 2 # requested at retina size by default and scaled down at point of use with css
 
         gravatar_url = "//www.gravatar.com/avatar/" + hashlib.md5(email.lower()).hexdigest() + "?"
         gravatar_url += urllib.urlencode({'s': str(size), 'd': default})
 
         return gravatar_url
 
-
 @register.tag
 def gravatar_url(parser, token):
     bits = token.split_contents()
