@@ -1,11 +1,15 @@
 from django import forms
 from django.forms.models import inlineformset_factory
-
+from django.utils.translation import ugettext_lazy as _
 import models
 
 
 class QueryForm(forms.Form):
-    query_string = forms.CharField(label='Search term(s)/phrase', help_text="Enter the full search string to match. An exact match is required for your Editors Picks to be displayed, wildcards are NOT allowed.", required=True)
+    query_string = forms.CharField(label=_('Search term(s)/phrase'), 
+        help_text=_("""Enter the full search string to match. An 
+        exact match is required for your Editors Picks to be 
+        displayed, wildcards are NOT allowed."""), 
+        required=True)
 
 
 class EditorsPickForm(forms.ModelForm):
