@@ -1,14 +1,14 @@
 import json
 
 from django.shortcuts import get_object_or_404
-from django.contrib.auth.decorators import login_required
+from django.contrib.auth.decorators import permission_required
 
 from wagtail.wagtailadmin.modal_workflow import render_modal_workflow
 
 from wagtail.wagtailsnippets.views.snippets import get_content_type_from_url_params, get_snippet_type_name
 
 
-@login_required
+@permission_required('wagtailadmin.access_admin')
 def choose(request, content_type_app_name, content_type_model_name):
     content_type = get_content_type_from_url_params(content_type_app_name, content_type_model_name)
     model = content_type.model_class()
@@ -27,7 +27,7 @@ def choose(request, content_type_app_name, content_type_model_name):
     )
 
 
-@login_required
+@permission_required('wagtailadmin.access_admin')
 def chosen(request, content_type_app_name, content_type_model_name, id):
     content_type = get_content_type_from_url_params(content_type_app_name, content_type_model_name)
     model = content_type.model_class()
